# setup.py
from setuptools import setup, find_packages

setup(
    name='NatanStanek',
    version='0.12',
    description='A simple demonstration package for NatanStanek',
    url='https://github.com/JacoBSmitH101/NatanStanek',
    author='James Mortimer',
    author_email='jamesmortimer@bournside.smells.uk',
    license='MIT',
    packages=find_packages(),
    zip_safe=False
)
